@@ -455,6 +455,9 @@ class Space_evenly_per_stroke(object):
                         fy = interp1d(t, y, kind='linear')
                         failed = False
                     except Exception as e:
+                        logging.debug("len(stroke) = %i", len(stroke))
+                        logging.debug("len(x) = %i", len(x))
+                        logging.debug("len(y) = %i", len(y))
                         raise e
 
                 for x, y, t in zip(fx(tnew), fy(tnew), tnew):
